// Специальный тип желудя для обработки определений желудей.
//
// Аналог &Напильника для `ОпределениеЖелудя`. Срабатывает каждый раз, когда в контекст добавляется новое
// определение желудя. При добавлении самой Приемки в контекст, все ранее добавленные определения желудей
// передаются в Приемку для проверки.
//
// Класс, помеченный аннотацией `&Приемка`, должен реализовать следующий интерфейс:
// * `Процедура ПриДобавленииОпределенияЖелудя(ОпределениеЖелудя) Экспорт`
//
// Каждая `&Приемка` так же имеет `&Характер("Компанейский")`, `&Прозвище("Приемка")` и `&Спецификация("Инициализация")`
//
// Размещается над конструктором класса.
//
// Параметры:
//   Значение - Строка - Имя желудя, под которым приемка добавляется в контекст Поделки.
//
// Пример:
//
// Процедура ПриДобавленииОпределенияЖелудя(ОпределениеЖелудя) Экспорт
// .   Сообщить("Определение желудя: " + ОпределениеЖелудя.Имя());
// КонецПроцедуры
// .
// &Приемка
// Процедура ПриСозданииОбъекта()
// КонецПроцедуры
//
&Аннотация("Приемка")
&Прозвище("Приемка")
&Характер("Компанейский")
&Спецификация("Инициализация")
Процедура ПриСозданииОбъекта(Значение = "")
КонецПроцедуры
